!==========================================================================================
****f* SuSeFLAV/oneloophiggs.f/higgs_analytical 
*  NAME
*    subroutine higgs_analytical
*  SYNOPSIS
*    Computes One loop correction(analytical) to cp even higgs boson and 
*    light higgs. 
*
*  FUNCTION
*     The routine calcultes one loop correction to cp even higgs boson.
*     hep-ph/ 9903404, hep-ph/0002213  - analytical expression for light higgs and 
*     CP- even higgs
*
*  INPUTS
*
*     alph3                          -  g3/(16 * pi^2)
*     mt                             -  running masses of top, bottom and tau
*     yuRG,ydRG,yeRG                 - (3 X 3) Yukawas
*     AURG                           - (3 X 3) Trilinear couplings
*     modmu                          - modulus of the \mu paramter 
*     vev1,vev2                      - vacuum expectation values of the two 
*                                      higgs doublet fields
*     M3t                            - Gaugino mass at msusy
*     tanbeta                        - the ratio of the vevs of the 
*                                      two Higgs doublet fields.
*     SUegg   =  6 eigenvalues of UP-Squark mass matrix.
*
*  RESULT
*     sigphi1,sigphi2,
*     sigphi12,sig2phi2
*     sig2phi2yuk         - elements of One loop corrections.
*  
*  EXAMPLE
*
*     SUBROUTINE higgs_analytical(MT,tanbeta,SUegg,AURG,sgnmu,modmu,
*     $     pizzT,piwwT,alph3,sigphi1,sigphi2,
*     $     sigphi12,sig2phi2,sig2phi2yuk)
*     
*  NOTES
*    1. q, the energy scale at which the corrections are added = msusy.
*    2. Conventions and notations followed are that of BPMZ.
*
*  BUGS
*    ---
*  SEE ALSO
*
******
* You can use this space for remarks that should not be included
* in the documentation.
C****C

!=====================================================================================================

      SUBROUTINE higgs_analytical(MT,tanbeta,SUegg,AURG,sgnmu,modmu,
     $     alph3,sigphi1,sigphi2,
     $     sigphi12,sig2phi2,sig2phi2yuk)

      IMPLICIT NONE
      
      DOUBLE PRECISION MT, tanbeta, SUegg(6), AURG(3,3), modmu
      DOUBLE PRECISION sigphi1,sigphi2,sigphi12,alph3,beta
      DOUBLE PRECISION Msy, lda, sw2, Mzr, Mtlr,sgnmu
      double precision sig2phi2,sig2phi12,sig2phi1,sig2phi2yuk
      DOUBLE PRECISION sinsqthw_susy,alph,Gf,alphas

      common/sinsq_susy/sinsqthw_susy

      common/gauge/alph,Gf,alphas

!----------------------------------------
      include 'stdinputs.h'
!---------------------------------------


      beta = datan(tanbeta)
      
      Mzr = dsqrt((MZ*MZ))


      sw2 = sinsqthw_susy 

      lda = ((1.d0/8.d0) - sw2/3.d0 + ((4.d0 * sw2**2.d0)/9.d0))

      Msy = (SUegg(1)*SUegg(2) + Mt**2.d0 * (SUegg(1) + SUegg(2))
     $     + Mt**4.d0)**(0.25d0)

      Mtlr = (AURG(3,3) - sgnmu*modmu/tanbeta)
      

      sigphi1 = (Gf * dsqrt(2.d0) * Mzr**4.d0 * lda * 
     $     (dcos(beta))**2.d0 * 2.d0 * dlog(MT/Msy))
     $     / (pi * pi)

      sigphi12 = Gf * dsqrt(2.d0) * Mzr * Mzr * 
     $     ( (- 3.d0 * Mt**2.d0 /8.d0) +  (Mzr * Mzr * lda *
     $     (dsin(datan(tanbeta)))**2.d0)) * 2.d0 * dlog(Mt/Msy) 
     $     / (pi * pi * tanbeta)

      sigphi2 = (Gf * dsqrt(2.d0) * Mt**4.d0/
     $     (pi * pi * 8.d0 * dsin(datan(tanbeta))**2.d0)) *
     $     ((-2.d0*(Mzr/Mt)**2.d0) + (11.d0/10.d0 *(Mzr/Mt)**4.d0) +
     $     ((12.d0 - (6.d0*(Mzr*dsin(datan(tanbeta))/Mt)**2.d0) +
     $     (8.d0 * (Mzr*dsin(datan(tanbeta))/Mt)**4.d0 * lda) ) *
     $     2.d0 * dlog(Mt/Msy)) + 
     $     ((Mtlr/Msy)**2.d0 * (-12.d0 + (2.d0 * Mzr/ Mt)**2.d0 +
     $     6.d0 * (Mt/Msy)**2.d0)) +
     $     ((Mtlr/Msy)**4.d0 * (1.d0 - (2.d0*Mt/Msy)**2.d0 + 
     $     3.d0 * (Mt/Msy)**4.d0)) +
     $     ((Mtlr/Msy)**6.d0 * (3.d0*(Mt/Msy)**2.d0 - 
     $     12.d0*(Mt/Msy)**4.d0 +
     $     10.d0*(Mt/Msy)**6.d0))/5.d0 + 
     $     ((Mtlr/Msy)**8.d0 * (3.d0*(Mt/Msy)**4.d0 - 
     $     12.d0*(Mt/Msy)**6.d0+
     $     10.5d0*(Mt/Msy)**8.d0))/7.d0)

      sig2phi1  = 0.d0

      sig2phi12 = 0.d0

      sig2phi2  = ((Gf * dsqrt(2.d0) * 4.d0 * alph3 *  mt**4.d0)/
     $     (pi**3.d0 * dsin(beta)**2.d0)) * (3.d0 * 
     $     (dlog((mt/Msy)**2.d0))**2.d0 - 12.d0 * dlog(mt/Msy) - 
     $     6.d0 * (MtLR/Msy) - 6.d0 * (MtLR/Msy)**2.d0 * dlog(mt/Msy) +
     $     (3.d0/4.d0) * (MtLR/Msy)**4.d0)

      sig2phi2yuk = - (9.d0/(16.d0 * pi**4.d0)) * 
     $     ((Gf*Gf * mt**6.d0)/dsin(beta)**2.d0) * 
     $     ((2.d0 * dlog(mt/Msy))**2.d0 + 4.d0 * (MtLR/Msy)**2.d0 * !<--- sign before the second term reversed... 
     $     dlog(mt/Msy) + (1.d0/3.d0) * (MtLR/Msy)**4.d0 * dlog(mt/Msy))
      

      RETURN
      END SUBROUTINE 

!===========================================================================

